@@ -22,7 +22,7 @@ from sqlalchemy import types
 from sqlalchemy import util
 # TODO shouldn't use mysql type
 from sqlalchemy.databases import mysql
-from sqlalchemy.engine import default, Engine, Connection
+from sqlalchemy.engine import default, Engine, Connection, URL
 from sqlalchemy.sql import compiler
 from sqlalchemy.sql.compiler import SQLCompiler
 
@@ -225,11 +225,10 @@ class E6xDialect(default.DefaultDialect):
 
     def create_connect_args(self, url):
         db = None
-        _logger.info("got url query {query}".format(query=url.query))
         if url.query.get("schema"):
             db = url.query.get("schema")
         kwargs = {
-            "host": url.hostname,
+            "host": url.host,
             "port": url.port or 10000,
             "scheme": self.scheme,
             "username": url.username or None,
